fpylll: Python interface for FPLLL
==================================

Description
-----------

A Python interface for https://github.com/fplll/fplll (Lattice algorithms using floating-point arithmetic)

License
-------

GPL version 2 or later


Upstream Contact
----------------

https://github.com/fplll/fpylll

Dependencies
------------

-  Cython
-  fplll
-  Sage (optional)
-  NumPy (optional)
